pub struct MessageStreamPrepare {
pub flags: u8,
pub prepare_lsn: u64,
pub end_lsn: u64,
pub prepare_timestamp: u64,
pub transaction_id: u32,
pub gid_size: u32,
pub gid: StringWithSize,
}Fields
flags: u8prepare_lsn: u64end_lsn: u64prepare_timestamp: u64transaction_id: u32gid_size: u32gid: StringWithSizeTrait Implementations
Sourceimpl BinRead for MessageStreamPrepare
impl BinRead for MessageStreamPrepare
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreAuto Trait Implementations
impl Freeze for MessageStreamPrepare
impl RefUnwindSafe for MessageStreamPrepare
impl Send for MessageStreamPrepare
impl Sync for MessageStreamPrepare
impl Unpin for MessageStreamPrepare
impl UnwindSafe for MessageStreamPrepare