pub struct MessageUpdate {
pub transaction_id: u16,
pub relation_oid: u16,
pub key_or_old_tuple: Option<KeyOrOldTupleData>,
pub new_tuple: TupleData,
}Fields
transaction_id: u16relation_oid: u16key_or_old_tuple: Option<KeyOrOldTupleData>new_tuple: TupleDataTrait Implementations
Sourceimpl BinRead for MessageUpdate
impl BinRead for MessageUpdate
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreAuto Trait Implementations
impl Freeze for MessageUpdate
impl RefUnwindSafe for MessageUpdate
impl Send for MessageUpdate
impl Sync for MessageUpdate
impl Unpin for MessageUpdate
impl UnwindSafe for MessageUpdate